Module schema

Module schema 

SQLite schema helpers for the yugendb storage table.

The SQLite driver stores yugendb records through the same core model used by every driver:

namespace + collection + key -> serialised typed value

This module describes the storage schema used by the SQLite driver.

Structs

SqliteStorageSchema
Value object that describes the SQLite storage schema.

Constants

ALL_SCHEMA_STATEMENTS
All SQL statements needed to initialise the current SQLite schema.
CREATE_EXPIRES_AT_INDEX_SQL
SQL statement that creates the expiry lookup index.
CREATE_MIGRATION_METADATA_TABLE_SQL
SQL statement that creates schema migration bookkeeping.
CREATE_PREFIX_INDEX_SQL
SQL statement that creates the prefix scan index.
CREATE_STORE_TABLE_SQL
SQL statement that creates the main storage table.
MIGRATION_METADATA_TABLE_NAME
Metadata table used for SQLite schema migration bookkeeping.
SCHEMA_VERSION
Current schema version for the SQLite storage table.
STORE_TABLE_NAME
Main storage table used by the SQLite backend.

Functions

schema_statements
Returns all SQL statements needed to initialise the current SQLite schema.