SQLite schema helpers for the yugendb storage table.
The SQLite driver stores yugendb records through the same core model used by every driver:
namespace + collection + key -> serialised typed valueThis module describes the storage schema used by the SQLite driver.
Structs
- Sqlite
Storage Schema - Value object that describes the SQLite storage schema.
Constants
- ALL_
SCHEMA_ STATEMENTS - All SQL statements needed to initialise the current SQLite schema.
- CREATE_
EXPIRES_ AT_ INDEX_ SQL - SQL statement that creates the expiry lookup index.
- CREATE_
MIGRATION_ METADATA_ TABLE_ SQL - SQL statement that creates schema migration bookkeeping.
- CREATE_
PREFIX_ INDEX_ SQL - SQL statement that creates the prefix scan index.
- CREATE_
STORE_ TABLE_ SQL - SQL statement that creates the main storage table.
- MIGRATION_
METADATA_ TABLE_ NAME - Metadata table used for SQLite schema migration bookkeeping.
- SCHEMA_
VERSION - Current schema version for the SQLite storage table.
- STORE_
TABLE_ NAME - Main storage table used by the SQLite backend.
Functions
- schema_
statements - Returns all SQL statements needed to initialise the current SQLite schema.